package com.usky.dxtop.controller.web;


import com.usky.dxtop.common.constant.UserConstants;
import com.usky.dxtop.common.core.domain.AjaxResult;
import com.usky.dxtop.common.utils.SecurityUtils;
import com.usky.dxtop.controller.BaseController;
import com.usky.dxtop.model.QrCode;
import com.usky.dxtop.service.QrCodeService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

/**
 *  二维码管理
 *
 * @author yq
 * @since 2021-08-26
 */
@RestController
@RequestMapping("/dxtop/qrCode")
public class QrCodeController extends BaseController {


    @Autowired
    private QrCodeService qrCodeService;

    /**
     * 新增
     * @param qrCode
     * @return
     */
    @PostMapping
    public AjaxResult add(@RequestBody QrCode qrCode){
        if (UserConstants.NOT_UNIQUE.equals(qrCodeService.checkNameUnique(qrCode)))
        {
            return AjaxResult.error("新增二维码信息'" + qrCode.getName() + "'失败，二维码信息已存在");
        }
        return toAjax(qrCodeService.add(qrCode));

    }

    /**
     * 修改
     */
    @PutMapping
    public AjaxResult edit(@RequestBody QrCode qrCode)
    {
        if (UserConstants.NOT_UNIQUE.equals(qrCodeService.checkNameUnique(qrCode)))
        {
            return AjaxResult.error("修改二维码信息'" + qrCode.getName() + "'失败，二维码信息已存在");
        }
        qrCode.setUpdateBy(SecurityUtils.getUsername());
        return toAjax(qrCodeService.updateById(qrCode));
    }

    /**
     * 分页
     * @param
     * @return
     */
    @GetMapping("/list")
    public AjaxResult list(@RequestParam Integer current,
                           @RequestParam Integer size,
                           @RequestParam(required = false) String name)
    {
        return AjaxResult.success(qrCodeService.list(current, size, name));
    }


    /**
     * 删除
     */
    @DeleteMapping("/{id}")
    public AjaxResult remove(@PathVariable("id") Long id)
    {
        return toAjax(qrCodeService.remove(id));
    }
}

